@@ -1,20 +1,20 @@
 /* idna.c	Convert to or from IDN strings.
  * Copyright (C) 2002  Simon Josefsson
  *
- * This file is part of Libstringprep.
+ * This file is part of GNU Libidn.
  *
- * Libstringprep is free software; you can redistribute it and/or
+ * GNU Libidn is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * Libstringprep is distributed in the hope that it will be useful,
+ * GNU Libidn is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with Libstringprep; if not, write to the Free Software
+ * License along with GNU Libidn; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -57,7 +57,7 @@ idna_to_ascii (const unsigned long *in, size_t inlen,
 	       char *out, int allowunassigned, int usestd3asciirules)
 {
   size_t len, outlen;
-  unsigned long *src;
+  unsigned long *src; /* XXX don't need to copy data? */
   int rc;
 
   src = malloc (sizeof (in[0]) * inlen + 1);
@@ -172,7 +172,15 @@ step3:
    */
 
   {
-    /* XXX */
+    size_t i;
+    int match;
+
+    match = 1;
+    for (i = 0; match && i < strlen(IDNA_ACE_PREFIX); i++)
+      if (IDNA_ACE_PREFIX[i] != src[i])
+	match = 0;
+    if (match)
+      return IDNA_CONTAINS_ACE_PREFIX;
   }
 
   /*
