@@ -1,20 +1,20 @@
-/* toutf8.c	convert strings from system locale into UTF-8
+/* toutf8.c	Convert strings from system locale into UTF-8.
  * Copyright (C) 2002  Simon Josefsson
  *
- * This file is part of libstringprep.
+ * This file is part of GNU Libidn.
  *
- * Libstringprep is free software; you can redistribute it and/or
+ * GNU Libidn is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * Libstringprep is distributed in the hope that it will be useful,
+ * GNU Libidn is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with libstringprep; if not, write to the Free Software
+ * License along with GNU Libidn; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -172,14 +172,16 @@ again:
 const char *
 stringprep_locale_charset ()
 {
-  return NULL;
+  return "ASCII";
 }
 
 char *
 stringprep_convert (const char *str,
 		    const char *to_codeset, const char *from_codeset)
 {
-  return NULL;
+  fprintf(stderr, "warning: cannot convert data to UTF-8, returning source\n");
+  fprintf(stderr, "warning: this indicate a badly installed GNU Libidn\n");
+  return strdup(str);
 }
 
 #endif
