@@ -1,20 +1,20 @@
-/* tst_idna.c	Libstringprep self tests for idna_to_ascii().
+/* tst_idna.c	Self tests for idna_to_ascii().
  * Copyright (C) 2002  Simon Josefsson
  *
- * This file is part of Libstringprep.
+ * This file is part of GNU Libidn.
  *
- * Libstringprep is free software; you can redistribute it and/or modify
+ * GNU Libidn is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  *
- * Libstringprep is distributed in the hope that it will be useful,
+ * GNU Libidn is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Libstringprep; if not, write to the Free Software
+ * along with GNU Libidn; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -213,6 +213,13 @@ idna[] =
     0x305D, 0x306E, 0x30B9, 0x30D4, 0x30FC, 0x30C9, 0x3067}
   , IDNA_ACE_PREFIX "d9juau41awczczp", 0, 0, IDNA_SUCCESS, IDNA_SUCCESS}
   ,
+  { /* XXX depends on IDNA_ACE_PREFIX */
+    "ToASCII() with ACE prefix", 6 + 3,
+    {
+      'i', 'e', 's', 'g', '-', '-', 'f', 'o', 0x3067 },
+    IDNA_ACE_PREFIX "too long too long too long too long too long too "
+    "long too long too long too long too long ", 0, 0,
+    IDNA_CONTAINS_ACE_PREFIX, IDNA_PUNYCODE_ERROR}
 #if 0
   {
     "(S) -> $1.00 <-", 11,
@@ -289,10 +296,10 @@ main (int argc, char *argv[])
 		printf ("ERROR\n");
 	    }
 	  else if (debug)
-	    printf ("OK\n\n");
+	    printf ("OK\n");
 	}
       else if (debug)
-	printf ("OK\n\n");
+	printf ("OK\n");
 
       ucs4label = stringprep_utf8_to_ucs4 (idna[i].out, -1, &len);
 
@@ -306,14 +313,6 @@ main (int argc, char *argv[])
       rc = idna_to_unicode (ucs4label, len, tmp, &len2,
 			    idna[i].allowunassigned,
 			    idna[i].usestd3asciirules);
-      if (rc != idna[i].tounicoderc)
-	{
-	  fail ("IDNA entry %d failed: %d\n", i, rc);
-	  if (debug)
-	    printf ("FATAL\n");
-	  continue;
-	}
-
       if (debug)
 	{
 	  printf ("expected out:\n");
@@ -326,6 +325,14 @@ main (int argc, char *argv[])
 	  ucs4print (tmp, len2);
 	}
 
+      if (rc != idna[i].tounicoderc)
+	{
+	  fail ("IDNA entry %d failed: %d\n", i, rc);
+	  if (debug)
+	    printf ("FATAL\n");
+	  continue;
+	}
+
       if ((rc == IDNA_SUCCESS && (len2 != idna[i].inlen ||
 				  memcmp(idna[i].in, tmp, len2) != 0)) ||
 	  (rc != IDNA_SUCCESS && (len2 != len ||
@@ -335,6 +342,8 @@ main (int argc, char *argv[])
 	  if (debug)
 	    printf ("ERROR\n");
 	}
+      else if (debug)
+	printf ("OK\n\n");
 
     }
 
